<?php
namespace App\DataFixtures;

use App\Entity\Event;
use App\Entity\EventTeam;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Common\DataFixtures\DependentFixtureInterface;
use Doctrine\Persistence\ObjectManager;
use App\Entity\EventHero;

class EventFixtures extends Fixture implements DependentFixtureInterface
{

    public const REF_1 = 'event-1-reference';

    public const REF_2 = 'event-2-reference';

    public const REF_EVENT1_CHAR1 = 'event-1-char-1-reference';

    public const REF_EVENT1_TEAM1 = 'event-1-team-1-reference';

    public const REF_EVENT1_CHAR2 = 'event-1-char-2-reference';

    public const REF_EVENT1_TEAM2 = 'event-1-team-2-reference';

    public function load(ObjectManager $manager)
    {
        $heroUser1 = $this->getReference(UserFixtures::ADMIN_USER_REFERENCE)->getHeroes()[0];
        $heroUser2 = $this->getReference(UserFixtures::DUDE_USER_REFERENCE)->getHeroes()[0];

        $event1 = new Event(Event::FREE_BATTLE);
        $manager->persist($event1);

        $event2 = new Event(Event::TOURNAMENT);
        $manager->persist($event2);

        $eventTeam1 = new EventTeam($event1, 1, "A Team");
        $eventTeam2 = new EventTeam($event1, 2, "B Team");

        $manager->persist($eventTeam1);
        $manager->persist($eventTeam2);

        $eventHero1 = new EventHero($event1, $heroUser1, $eventTeam1);
        $eventHero2 = new EventHero($event1, $heroUser2, $eventTeam2);
        $manager->persist($eventHero1);
        $manager->persist($eventHero2);

        $manager->flush();

        $this->addReference(self::REF_1, $event1);
        $this->addReference(self::REF_2, $event2);
        $this->addReference(self::REF_EVENT1_CHAR1, $eventHero1);
        $this->addReference(self::REF_EVENT1_CHAR2, $eventHero2);
        $this->addReference(self::REF_EVENT1_TEAM1, $eventTeam1);
        $this->addReference(self::REF_EVENT1_TEAM2, $eventTeam2);
    }

    public function getDependencies()
    {
        return array(
            UserFixtures::class,
            HeroFixtures::class
        );
    }
}

