<?php
namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;

class Event
{

    const QUEST = 1;

    const TOURNAMENT = 2;

    const FREE_BATTLE = 3;

    const LEAGUE_MATCHDAY = 4;

    const RESERVED_5 = 5;

    const CLAN_BATTLE = 6;

    private ?int $id;

    private int $type = self::QUEST;

    private int $version = 1;

    private Collection $battles;

    private Collection $teams;

    public function __construct(int $type = self::QUEST)
    {
        $this->heroes = new ArrayCollection();
        $this->battles = new ArrayCollection();
        $this->type = $type;
        $this->teams = new ArrayCollection();
    }

    public function getType(): ?int
    {
        return $this->type;
    }

    public function setType(int $type): self
    {
        $this->type = $type;

        return $this;
    }

    public function getVersion(): ?int
    {
        return $this->version;
    }

    public function setVersion(int $version): self
    {
        $this->version = $version;

        return $this;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * @return Collection|EventBattle[]
     */
    public function getBattles(): Collection
    {
        return $this->battles;
    }

    public function addBattle(EventBattle $battle): self
    {
        if (!$this->battles->contains($battle)) {
            $this->battles[] = $battle;
            $battle->setEvent($this);
        }

        return $this;
    }

    public function removeBattle(EventBattle $battle): self
    {
        if ($this->battles->contains($battle)) {
            $this->battles->removeElement($battle);
            // set the owning side to null (unless already changed)
            if ($battle->getEvent() === $this) {
                $battle->setEvent(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|EventTeam[]
     */
    public function getTeams(): Collection
    {
        return $this->teams;
    }

    public function addTeam(EventTeam $team): self
    {
        if (!$this->teams->contains($team)) {
            $this->teams[] = $team;
            $team->setEvent($this);
        }

        return $this;
    }

    public function removeTeam(EventTeam $team): self
    {
        if ($this->teams->contains($team)) {
            $this->teams->removeElement($team);
            // set the owning side to null (unless already changed)
            if ($team->getEvent() === $this) {
                $team->setEvent(null);
            }
        }

        return $this;
    }
}

