<?php
namespace App\Security;

use App\Repository\UserRepository;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Security\Core\User\UserInterface;
use Symfony\Component\Security\Guard\AbstractGuardAuthenticator;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\Security\Core\User\UserProviderInterface;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Symfony\Component\HttpKernel\Exception\UnauthorizedHttpException;
use App\Entity\User;

class UrlAuthenticator extends AbstractGuardAuthenticator
{

    /**
     * Called on every request to decide if this authenticator should be
     * used for the request.
     * Returning false will cause this authenticator
     * to be skipped.
     */
    public function supports(Request $request)
    {
        return str_starts_with($request->getPathInfo(), "/main/");
    }

    /**
     * Called on every request.
     * Return whatever credentials you want to
     * be passed to getUser() as $credentials.
     */
    public function getCredentials(Request $request)
    {
        $result = preg_replace('#/main/([^/]+)/#i', '$1', $request->getPathInfo());
        return $result === $request->getPathInfo() ? null : $result;
    }

    public function getUser($credentials, UserProviderInterface $userProvider)
    {
        if (null === $credentials) {
            return null;
        }

        $user = new User();
        $user->setUsername($credentials);
        return $user;
    }

    public function checkCredentials($credentials, UserInterface $user)
    {
        // check credentials - e.g. make sure the password is valid
        // no credential check is needed in this case

        // return true to cause authentication success
        return true;
    }

    public function onAuthenticationSuccess(Request $request, TokenInterface $token, $providerKey)
    {
        // on success, let the request continue
        return null;
    }

    public function onAuthenticationFailure(Request $request, AuthenticationException $exception)
    {
        $message = strtr($exception->getMessageKey(), $exception->getMessageData());
        // or to translate this message
        // $this->translator->trans($exception->getMessageKey(), $exception->getMessageData())

        // This should translated by FOSRestBundle!
        throw new AccessDeniedHttpException($message);
    }

    /**
     * Called when authentication is needed, but it's not sent
     */
    public function start(Request $request, AuthenticationException $authException = null)
    {
        throw new UnauthorizedHttpException('', 'Authentication Required');
    }

    public function supportsRememberMe(): bool
    {
        return false;
    }
}
